# NVIDIA Quadro Drivers, second package
# 2016-2020 foo.li systeme + software

$packageName    = 'nvidia-quadro-drivers-b'
$version        = '452.57'
$fileType       = 'exe'
$silentArgs     = '-s -n'
$packagesearch  = 'NVIDIA Grafik*'
$unpackDir      = New-Item "${ENV:TEMP}\nvidiadriver" -ItemType Directory -Force
$unpackFile     = "${ENV:TEMP}\nvidiadriver.zip"
$setupFile  = Join-Path "$unpackDir" "setup.exe"

$WindowsVersion = (Get-WmiObject -Class Win32_OperatingSystem).Caption
if ( $WindowsVersion -match 'Windows 10' ) {
  $url = "https://de.download.nvidia.com/Windows/Quadro_Certified/$version/$version-quadro-desktop-notebook-win10-32bit-international-dch-whql.exe"
  $url64 = "https://de.download.nvidia.com/Windows/Quadro_Certified/$version/$version-quadro-desktop-notebook-win10-64bit-international-dch-whql.exe"
} else {
  Write-Host 'Win7 drivers are unmaintained. No guarantee this link will work...'
  $url = "http://de.download.nvidia.com/Windows/Quadro_Certified/$version/$version-quadro-grid-desktop-notebook-win8-win7-32bit-international-whql.exe"
  $url64 = "http://de.download.nvidia.com/Windows/Quadro_Certified/$version/$version-quadro-grid-desktop-notebook-win8-win7-64bit-international-whql.exe"
}

$card = (Get-WmiObject -Class win32_VideoController | Where { $_.Name -notlike '*video hook*' }).Name

if (!($card -like '*NVIDIA*')) {
    Write-Warning 'does not look like there is a NVIDIA card in this host'
    throw 'no nvidia card detected'
}

try {
    $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*')`
                -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packagesearch }
    if ($app -and ([version]$app.DisplayVersion -ge [version]$version)) {
        Write-Output $(
        'current NVIDIA Drivers are already installed. ' +
        'No need to download and install again. Otherwise uninstall first'
        )
    } else {
        Get-ChocolateyWebFile $packageName $unpackFile $url $url64
        Get-ChocolateyUnzip $unpackFile $unpackDir
        Remove-Item $unpackDir\Update.Core -Recurse -Force -ErrorAction SilentlyContinue
        Remove-Item $unpackDir\Display.Update -Recurse -Force -ErrorAction SilentlyContinue
        Remove-Item $unpackDir\ShadowPlay -Recurse -Force -ErrorAction SilentlyContinue
        Remove-Item $unpackDir\GFExperience* -Recurse -Force -ErrorAction SilentlyContinue
        Install-ChocolateyInstallPackage $packageName $fileType $silentArgs $setupFile
        Remove-Item $unpackDir -Recurse -Force -ErrorAction SilentlyContinue
    }
} catch {
    throw $_.Exception
}
